<?php
/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://#
 * @since      1.0.0
 *
 * @package    Ytautocaptioncrafter
 * @subpackage Ytautocaptioncrafter/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Ytautocaptioncrafter
 * @subpackage Ytautocaptioncrafter/includes
 * @author     Ytautocaptioncrafter <ytautocaptioncrafter@ytautocaptioncrafter.com>
 */ 
class Ytautocaptioncrafter {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Ytautocaptioncrafter_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		if (defined('YTAUTOCAPTIONCRAFTER_VERSION')) {
			$this->version = YTAUTOCAPTIONCRAFTER_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'Ytautocaptioncrafter';
        $this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Ytautocaptioncrafter_Loader. Orchestrates the hooks of the plugin.
	 * - Ytautocaptioncrafter_i18n. Defines internationalization functionality.
	 * - Ytautocaptioncrafter_Admin. Defines all hooks for the admin area.
	 * - Ytautocaptioncrafter_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/ytautocaptioncrafter-class-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/ytautocaptioncrafter-class-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/ytautocaptioncrafter-class-admin.php';

	    $this->loader = new Ytautocaptioncrafter_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Ytautocaptioncrafter_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Ytautocaptioncrafter_i18n();

		$this->loader->add_action('plugins_loaded', $plugin_i18n, 'load_plugin_textdomain');
		
	}
    /**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Ytautocaptioncrafter_Admin( $this->get_plugin_name(), $this->get_version() );
		
		$this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_styles');
		$this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts');
		$this->loader->add_action( 'admin_init', $plugin_admin, 'ytautocaptioncrafter_submit' );
		/**
		 * Add Menu in Dashboard 
		 */ 
		$this->loader->add_action('admin_menu', $plugin_admin, 'ytautocaptioncrafter_admin_menus');
		/**
		 * Chat GPT Meta box Setting post and custom type
		 */
		$this->loader->add_action('add_meta_boxes', $plugin_admin, 'ytautocaptioncrafter_add_custom_box');
		
		/**
		 * Chat GPT Meta box Setting post and custom type Save 
		 */
		$this->loader->add_action('save_post', $plugin_admin, 'ytautocaptioncrafter_save_postdata');
        /**
		 * Yt Container Api Verify & Ajax
		 */
		$this->loader->add_action('wp_ajax_nopriv_ytautocaptioncrafter_api_verify_save',$plugin_admin,'ytautocaptioncrafter_api_verify_save');
		$this->loader->add_action('wp_ajax_ytautocaptioncrafter_api_verify_save',$plugin_admin,'ytautocaptioncrafter_api_verify_save'); 
        /**
		 * Yt Container Api Disconnect
		 */
        $this->loader->add_action('wp_ajax_nopriv_ytautocaptioncrafter_api_disconnection',$plugin_admin,'ytautocaptioncrafter_api_disconnection');
		$this->loader->add_action('wp_ajax_ytautocaptioncrafter_api_disconnection',$plugin_admin,'ytautocaptioncrafter_api_disconnection'); 

		/**
	     * Yt Container Videos Filter 
	     */ 
		$this->loader->add_action('wp_ajax_nopriv_ytautocaptioncrafter_videos_filters',$plugin_admin,'ytautocaptioncrafter_videos_filters');
		$this->loader->add_action('wp_ajax_ytautocaptioncrafter_videos_filters',$plugin_admin,'ytautocaptioncrafter_videos_filters'); 
  
        /**
	     * Yt Container Videos Text Save in Post
         */
		$this->loader->add_action('wp_ajax_nopriv_ytautocaptioncrafter_videos_saveinpost',$plugin_admin,'ytautocaptioncrafter_videos_saveinpost');
		$this->loader->add_action('wp_ajax_ytautocaptioncrafter_videos_saveinpost',$plugin_admin,'ytautocaptioncrafter_videos_saveinpost');
		
		/**
		* Yt Container Videos General Api Setting ajax
		*/
		$this->loader->add_action('wp_ajax_nopriv_ytautocaptioncrafter_general_api_settings', $plugin_admin,'ytautocaptioncrafter_general_api_settings'); 
		$this->loader->add_action('wp_ajax_ytautocaptioncrafter_general_api_settings', $plugin_admin,'ytautocaptioncrafter_general_api_settings'); 
	   	
		/**
		* Yt Container Chat GPT Content Generator 
	    */
		$this->loader->add_action('wp_ajax_nopriv_ytautocaptioncrafter_content_generator', $plugin_admin,'ytautocaptioncrafter_content_generator');
		$this->loader->add_action('wp_ajax_ytautocaptioncrafter_content_generator', $plugin_admin,'ytautocaptioncrafter_content_generator');
    
		/**
		* Yt Container Chat GPT Image Generator
		*/
		$this->loader->add_action('wp_ajax_nopriv_ytautocaptioncrafter_openai_img_generator', $plugin_admin,'ytautocaptioncrafter_openai_img_generator'); 
		$this->loader->add_action('wp_ajax_ytautocaptioncrafter_openai_img_generator', $plugin_admin,'ytautocaptioncrafter_openai_img_generator'); 
	}
    /**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Ytautocaptioncrafter_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}